# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## 0.2.3 - 2022-02-28
- Add ampl_notebook to simplify jupyter notebooks.

## 0.2.2 - 2022-02-25
- Add ampl_license_cell and ampl_installer_cell for jupyter notebooks.

## 0.2.1 - 2022-02-21
- Fix SageMaker Studio Lab detection in cloud_platform_name().

## 0.2.0 - 2022-02-10
- Add cloud_platform_name to guess the name of the cloud platform currently running on.

## 0.1.0 - 2022-02-08
- Initial release with module_installer and ampl_installer.
